==> qjs-wrapper-v1.3.tar.gz: qjs-wrapper-v1.3/include/dronedge.h <==
#ifndef __DRONEDGE_H__
#define __DRONEDGE_H__

#include <open62541/server.h>
#include "mavsdk_wrapper.h"
#include "pubsub.h"

struct messageNode {
  char *message;
  struct messageNode *next;
};
typedef struct {
  struct messageNode *head;
  struct messageNode *tail;
} MessageQueue;

UA_Double positionArray[POSITION_ARRAY_SIZE] = { 0 };
UA_UInt32 positionArrayDims[] = {POSITION_ARRAY_SIZE};

UA_Double speedArray[SPEED_ARRAY_SIZE] = { 0 };
UA_UInt32 speedArrayDims[] = {SPEED_ARRAY_SIZE};

UA_String message = {
    .length = 0,
    .data = NULL,
};

VariableData droneVariableArray[] = {
    {
        .name = "positionArray",
        .typeName = "Position Array Type",
        .description = "Position Array",
        .value = &positionArray,
        .type = UA_TYPES_DOUBLE,
        .builtInType = UA_NS0ID_DOUBLE,
        .valueRank = UA_VALUERANK_ONE_DIMENSION,
        .arrayDimensionsSize = 1,
        .arrayDimensions = positionArrayDims,
        .getter.getArray = mavsdk_getPositionArray,
    },
    {
        .name = "speedArray",
        .typeName = "Speed Array Type",
        .description = "Speed Array",
        .value = &speedArray,
        .type = UA_TYPES_FLOAT,
        .builtInType = UA_NS0ID_FLOAT,
        .valueRank = UA_VALUERANK_ONE_DIMENSION,
        .arrayDimensionsSize = 1,
        .arrayDimensions = speedArrayDims,
        .getter.getArray = mavsdk_getSpeedArray,
    },
    {
        .name = "message",
        .description = "Message to send to the other drones",
        .value = &message,
        .type = UA_TYPES_STRING,
        .builtInType = UA_NS0ID_STRING,
        .valueRank = UA_VALUERANK_SCALAR,
        .arrayDimensionsSize = 0,
        .arrayDimensions = NULL,
        .getter.getString = get_message,
    },
};

#endif /* __DRONEDGE_H__ */

==> qjs-wrapper-v2.0.tar.gz: qjs-wrapper-v2.0/include/dronedge.h <==
#ifndef __DRONEDGE_H__
#define __DRONEDGE_H__

#include <open62541/server.h>
#include "autopilot_wrapper.h"
#include "pubsub.h"

#define DRONE_VARIABLE_NB 3
#define SUBSCRIBER_VARIABLE_NB 1
struct messageNode {
  char *message;
  struct messageNode *next;
};
typedef struct {
  struct messageNode *head;
  struct messageNode *tail;
} MessageQueue;

UA_Int64 positionArray[POSITION_ARRAY_SIZE] = { 0 };
UA_UInt32 positionArrayDims[] = {POSITION_ARRAY_SIZE};

UA_Double speedArray[SPEED_ARRAY_SIZE] = { 0 };
UA_UInt32 speedArrayDims[] = {SPEED_ARRAY_SIZE};

UA_String message = {
    .length = 0,
    .data = NULL,
};

VariableData droneVariableArray[] = {
    {
        .name = "positionArray",
        .typeName = "Position Array Type",
        .description = "Position Array",
        .value = &positionArray,
        .type = UA_TYPES_INT64,
        .builtInType = UA_NS0ID_INT64,
        .valueRank = UA_VALUERANK_ONE_DIMENSION,
        .arrayDimensionsSize = 1,
        .arrayDimensions = positionArrayDims,
        .getter.getArray = getPositionArray,
    },
    {
        .name = "speedArray",
        .typeName = "Speed Array Type",
        .description = "Speed Array",
        .value = &speedArray,
        .type = UA_TYPES_FLOAT,
        .builtInType = UA_NS0ID_FLOAT,
        .valueRank = UA_VALUERANK_ONE_DIMENSION,
        .arrayDimensionsSize = 1,
        .arrayDimensions = speedArrayDims,
        .getter.getArray = getSpeedArray,
    },
    {
        .name = "message",
        .description = "Message to send to the other drones",
        .value = &message,
        .type = UA_TYPES_STRING,
        .builtInType = UA_NS0ID_STRING,
        .valueRank = UA_VALUERANK_SCALAR,
        .arrayDimensionsSize = 0,
        .arrayDimensions = NULL,
        .getter.getString = get_message,
    },
};

VariableStruct droneVariables = {
    .nbVariable = DRONE_VARIABLE_NB,
    .variableArray = droneVariableArray,
};

VariableData subscriberVariableArray[] = {
    {
        .name = "message",
        .description = "Message to send to the other drones",
        .value = &message,
        .type = UA_TYPES_STRING,
        .builtInType = UA_NS0ID_STRING,
        .valueRank = UA_VALUERANK_SCALAR,
        .arrayDimensionsSize = 0,
        .arrayDimensions = NULL,
        .getter.getString = get_message,
    },
};

VariableStruct subscriberVariables = {
    .nbVariable = SUBSCRIBER_VARIABLE_NB,
    .variableArray = subscriberVariableArray,
};

void Subscriber_log(void *context, UA_LogLevel level, UA_LogCategory category,
                    const char *msg, va_list args);

#endif /* __DRONEDGE_H__ */
